@@ -2,7 +2,7 @@ import logging
 
 from boto3.resources.action import ServiceAction, WaiterAction
 from boto3.resources.params import create_request_parameters
-from botocore import xform_name
+from boto3.resources.action import xform_name
 
 from aioboto3.resources.response import AIOResourceHandler, AIORawHandler
 
@@ -19,7 +19,8 @@ class AIOServiceAction(ServiceAction):
         if resource_response_model:
             self._response_handler = AIOResourceHandler(
                 search_path=resource_response_model.path,
-                factory=factory, resource_model=resource_response_model,
+                factory=factory,
+                resource_model=resource_response_model,
                 service_context=service_context,
                 operation_name=action_model.request.operation
             )
