@@ -65,7 +65,7 @@ def s3_key_name() -> str:
 
 
 @pytest_asyncio.fixture
-async def dynamodb_resource(request, region: str, config: AioConfig, event_loop, dynamodb2_server: str) -> "ServiceResource":
+async def dynamodb_resource(request, region: str, config: AioConfig, dynamodb2_server: str) -> "ServiceResource":
     session = Session(region_name=region, **moto_config())
 
     async with session.resource('dynamodb', region_name=region, endpoint_url=dynamodb2_server, config=config) as resource:
@@ -73,7 +73,7 @@ async def dynamodb_resource(request, region: str, config: AioConfig, event_loop,
 
 
 @pytest_asyncio.fixture
-async def s3_client(request, region: str, config: AioConfig, event_loop, s3_server: str, bucket_name: str) -> "S3":
+async def s3_client(request, region: str, config: AioConfig, s3_server: str, bucket_name: str) -> "S3":
     session = Session(region_name=region, **moto_config())
 
     async with session.client('s3', region_name=region, endpoint_url=s3_server, config=config) as client:
@@ -81,7 +81,7 @@ async def s3_client(request, region: str, config: AioConfig, event_loop, s3_serv
 
 
 @pytest_asyncio.fixture
-async def s3_resource(request, region: str, config: AioConfig, event_loop, s3_server: str, bucket_name: str) -> "ServiceResource":
+async def s3_resource(request, region: str, config: AioConfig, s3_server: str, bucket_name: str) -> "ServiceResource":
     session = Session(region_name=region, **moto_config())
 
     async with session.resource('s3', region_name=region, endpoint_url=s3_server, config=config) as resource:
@@ -123,7 +123,7 @@ def create_fake_session(base_class: Type[T], url_overrides: Dict[str, str]) -> T
 
 
 @pytest.fixture(scope='function')
-def moto_patch(request, region, config, event_loop, s3_server, kms_server):
+def moto_patch(request, region, config, s3_server, kms_server):
     FakeAioboto3Session = create_fake_session(Session, {
         's3': s3_server,
         'kms': kms_server
